auth

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 7, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// if we expect that the user of the function may be interested with concrete error,
	// it's a good idea to provide variable with this error
	ErrNoUserInContext = errors.New("no user in context")
)

Functions

func NewGcGrpcServerToken

func NewGcGrpcServerToken(grpcAddr string) credentials.PerRPCCredentials

Types

type User

type User struct {
	UUID  string
	Email string
	Role  string

	DisplayName string
}

func UserFromCtx

func UserFromCtx(ctx context.Context) (User, error)

Jump to