Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterBFFHTTPServer(s *http.Server, srv BFFHTTPServer)
- func RegisterBFFServer(s grpc.ServiceRegistrar, srv BFFServer)
- type BFFClient
- type BFFHTTPClient
- type BFFHTTPClientImpl
- func (c *BFFHTTPClientImpl) ApproveRescheduleTraining(ctx context.Context, in *v1.ApproveRescheduleTrainingRequest, ...) (*emptypb.Empty, error)
- func (c *BFFHTTPClientImpl) CancelTraining(ctx context.Context, in *v1.CancelTrainingRequest, opts ...http.CallOption) (*emptypb.Empty, error)
- func (c *BFFHTTPClientImpl) CreateTraining(ctx context.Context, in *v1.CreateTrainingRequest, opts ...http.CallOption) (*v1.CreateTrainingResponse, error)
- func (c *BFFHTTPClientImpl) GetTrainerAvailableHours(ctx context.Context, in *GetTrainerAvailableHoursRequest, ...) (*GetTrainerAvailableHoursRespone, error)
- func (c *BFFHTTPClientImpl) GetTraining(ctx context.Context, in *emptypb.Empty, opts ...http.CallOption) (*v1.GetTrainingResponse, error)
- func (c *BFFHTTPClientImpl) MakeHourAvailable(ctx context.Context, in *MakeHourAvailableRequest, opts ...http.CallOption) (*emptypb.Empty, error)
- func (c *BFFHTTPClientImpl) MakeHourUnavailable(ctx context.Context, in *MakeHourUnavailableRequest, opts ...http.CallOption) (*emptypb.Empty, error)
- func (c *BFFHTTPClientImpl) RejectRescheduleTraining(ctx context.Context, in *v1.RejectRescheduleTrainingRequest, ...) (*emptypb.Empty, error)
- func (c *BFFHTTPClientImpl) RequestRescheduleTraining(ctx context.Context, in *v1.RequestRescheduleTrainingRequest, ...) (*emptypb.Empty, error)
- func (c *BFFHTTPClientImpl) RescheduleTraining(ctx context.Context, in *v1.RescheduleTrainingRequest, opts ...http.CallOption) (*emptypb.Empty, error)
- type BFFHTTPServer
- type BFFServer
- type GetTrainerAvailableHoursRequest
- func (*GetTrainerAvailableHoursRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetTrainerAvailableHoursRequest) GetDateFrom() *timestamppb.Timestamp
- func (x *GetTrainerAvailableHoursRequest) GetDateTo() *timestamppb.Timestamp
- func (*GetTrainerAvailableHoursRequest) ProtoMessage()
- func (x *GetTrainerAvailableHoursRequest) ProtoReflect() protoreflect.Message
- func (x *GetTrainerAvailableHoursRequest) Reset()
- func (x *GetTrainerAvailableHoursRequest) String() string
- type GetTrainerAvailableHoursRespone
- func (*GetTrainerAvailableHoursRespone) Descriptor() ([]byte, []int)deprecated
- func (x *GetTrainerAvailableHoursRespone) GetDates() []*GetTrainerAvailableHoursRespone_Date
- func (*GetTrainerAvailableHoursRespone) ProtoMessage()
- func (x *GetTrainerAvailableHoursRespone) ProtoReflect() protoreflect.Message
- func (x *GetTrainerAvailableHoursRespone) Reset()
- func (x *GetTrainerAvailableHoursRespone) String() string
- type GetTrainerAvailableHoursRespone_Date
- func (*GetTrainerAvailableHoursRespone_Date) Descriptor() ([]byte, []int)deprecated
- func (x *GetTrainerAvailableHoursRespone_Date) GetDate() *timestamppb.Timestamp
- func (x *GetTrainerAvailableHoursRespone_Date) GetHasFreeHours() bool
- func (x *GetTrainerAvailableHoursRespone_Date) GetHours() []*GetTrainerAvailableHoursRespone_Hour
- func (*GetTrainerAvailableHoursRespone_Date) ProtoMessage()
- func (x *GetTrainerAvailableHoursRespone_Date) ProtoReflect() protoreflect.Message
- func (x *GetTrainerAvailableHoursRespone_Date) Reset()
- func (x *GetTrainerAvailableHoursRespone_Date) String() string
- type GetTrainerAvailableHoursRespone_Hour
- func (*GetTrainerAvailableHoursRespone_Hour) Descriptor() ([]byte, []int)deprecated
- func (x *GetTrainerAvailableHoursRespone_Hour) GetAvailable() bool
- func (x *GetTrainerAvailableHoursRespone_Hour) GetHasTrainingScheduled() bool
- func (x *GetTrainerAvailableHoursRespone_Hour) GetHour() *timestamppb.Timestamp
- func (*GetTrainerAvailableHoursRespone_Hour) ProtoMessage()
- func (x *GetTrainerAvailableHoursRespone_Hour) ProtoReflect() protoreflect.Message
- func (x *GetTrainerAvailableHoursRespone_Hour) Reset()
- func (x *GetTrainerAvailableHoursRespone_Hour) String() string
- type IsHourAvailableRequest
- func (*IsHourAvailableRequest) Descriptor() ([]byte, []int)deprecated
- func (x *IsHourAvailableRequest) GetTime() *timestamppb.Timestamp
- func (*IsHourAvailableRequest) ProtoMessage()
- func (x *IsHourAvailableRequest) ProtoReflect() protoreflect.Message
- func (x *IsHourAvailableRequest) Reset()
- func (x *IsHourAvailableRequest) String() string
- type IsHourAvailableResponse
- func (*IsHourAvailableResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsHourAvailableResponse) GetIsAvailable() bool
- func (*IsHourAvailableResponse) ProtoMessage()
- func (x *IsHourAvailableResponse) ProtoReflect() protoreflect.Message
- func (x *IsHourAvailableResponse) Reset()
- func (x *IsHourAvailableResponse) String() string
- type MakeHourAvailableRequest
- func (*MakeHourAvailableRequest) Descriptor() ([]byte, []int)deprecated
- func (x *MakeHourAvailableRequest) GetTime() []*timestamppb.Timestamp
- func (*MakeHourAvailableRequest) ProtoMessage()
- func (x *MakeHourAvailableRequest) ProtoReflect() protoreflect.Message
- func (x *MakeHourAvailableRequest) Reset()
- func (x *MakeHourAvailableRequest) String() string
- type MakeHourUnavailableRequest
- func (*MakeHourUnavailableRequest) Descriptor() ([]byte, []int)deprecated
- func (x *MakeHourUnavailableRequest) GetTime() []*timestamppb.Timestamp
- func (*MakeHourUnavailableRequest) ProtoMessage()
- func (x *MakeHourUnavailableRequest) ProtoReflect() protoreflect.Message
- func (x *MakeHourUnavailableRequest) Reset()
- func (x *MakeHourUnavailableRequest) String() string
- type UnimplementedBFFServer
- func (UnimplementedBFFServer) ApproveRescheduleTraining(context.Context, *v1.ApproveRescheduleTrainingRequest) (*emptypb.Empty, error)
- func (UnimplementedBFFServer) CancelTraining(context.Context, *v1.CancelTrainingRequest) (*emptypb.Empty, error)
- func (UnimplementedBFFServer) CreateTraining(context.Context, *v1.CreateTrainingRequest) (*v1.CreateTrainingResponse, error)
- func (UnimplementedBFFServer) GetTrainerAvailableHours(context.Context, *GetTrainerAvailableHoursRequest) (*GetTrainerAvailableHoursRespone, error)
- func (UnimplementedBFFServer) GetTraining(context.Context, *emptypb.Empty) (*v1.GetTrainingResponse, error)
- func (UnimplementedBFFServer) IsHourAvailable(context.Context, *IsHourAvailableRequest) (*IsHourAvailableResponse, error)
- func (UnimplementedBFFServer) MakeHourAvailable(context.Context, *MakeHourAvailableRequest) (*emptypb.Empty, error)
- func (UnimplementedBFFServer) MakeHourUnavailable(context.Context, *MakeHourUnavailableRequest) (*emptypb.Empty, error)
- func (UnimplementedBFFServer) RejectRescheduleTraining(context.Context, *v1.RejectRescheduleTrainingRequest) (*emptypb.Empty, error)
- func (UnimplementedBFFServer) RequestRescheduleTraining(context.Context, *v1.RequestRescheduleTrainingRequest) (*emptypb.Empty, error)
- func (UnimplementedBFFServer) RescheduleTraining(context.Context, *v1.RescheduleTrainingRequest) (*emptypb.Empty, error)
- func (UnimplementedBFFServer) ScheduleTraining(context.Context, *UpdateHourRequest) (*emptypb.Empty, error)
- type UnsafeBFFServer
- type UpdateHourRequest
- func (*UpdateHourRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateHourRequest) GetTime() *timestamppb.Timestamp
- func (*UpdateHourRequest) ProtoMessage()
- func (x *UpdateHourRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateHourRequest) Reset()
- func (x *UpdateHourRequest) String() string
Constants ¶
const ( BFF_IsHourAvailable_FullMethodName = "/bff.BFF/IsHourAvailable" BFF_ScheduleTraining_FullMethodName = "/bff.BFF/ScheduleTraining" BFF_GetTrainerAvailableHours_FullMethodName = "/bff.BFF/GetTrainerAvailableHours" BFF_MakeHourAvailable_FullMethodName = "/bff.BFF/MakeHourAvailable" BFF_GetTraining_FullMethodName = "/bff.BFF/GetTraining" BFF_CreateTraining_FullMethodName = "/bff.BFF/CreateTraining" BFF_CancelTraining_FullMethodName = "/bff.BFF/CancelTraining" BFF_RescheduleTraining_FullMethodName = "/bff.BFF/RescheduleTraining" BFF_ApproveRescheduleTraining_FullMethodName = "/bff.BFF/ApproveRescheduleTraining" BFF_RequestRescheduleTraining_FullMethodName = "/bff.BFF/RequestRescheduleTraining" BFF_RejectRescheduleTraining_FullMethodName = "/bff.BFF/RejectRescheduleTraining" )
const OperationBFFApproveRescheduleTraining = "/bff.BFF/ApproveRescheduleTraining"
const OperationBFFCancelTraining = "/bff.BFF/CancelTraining"
const OperationBFFCreateTraining = "/bff.BFF/CreateTraining"
const OperationBFFGetTrainerAvailableHours = "/bff.BFF/GetTrainerAvailableHours"
const OperationBFFGetTraining = "/bff.BFF/GetTraining"
const OperationBFFMakeHourAvailable = "/bff.BFF/MakeHourAvailable"
const OperationBFFRejectRescheduleTraining = "/bff.BFF/RejectRescheduleTraining"
const OperationBFFRequestRescheduleTraining = "/bff.BFF/RequestRescheduleTraining"
const OperationBFFRescheduleTraining = "/bff.BFF/RescheduleTraining"
Variables ¶
var BFF_ServiceDesc = grpc.ServiceDesc{ ServiceName: "bff.BFF", HandlerType: (*BFFServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "IsHourAvailable", Handler: _BFF_IsHourAvailable_Handler, }, { MethodName: "ScheduleTraining", Handler: _BFF_ScheduleTraining_Handler, }, { MethodName: "GetTrainerAvailableHours", Handler: _BFF_GetTrainerAvailableHours_Handler, }, { MethodName: "MakeHourAvailable", Handler: _BFF_MakeHourAvailable_Handler, }, { MethodName: "MakeHourUnavailable", Handler: _BFF_MakeHourUnavailable_Handler, }, { MethodName: "GetTraining", Handler: _BFF_GetTraining_Handler, }, { MethodName: "CreateTraining", Handler: _BFF_CreateTraining_Handler, }, { MethodName: "CancelTraining", Handler: _BFF_CancelTraining_Handler, }, { MethodName: "RescheduleTraining", Handler: _BFF_RescheduleTraining_Handler, }, { MethodName: "ApproveRescheduleTraining", Handler: _BFF_ApproveRescheduleTraining_Handler, }, { MethodName: "RequestRescheduleTraining", Handler: _BFF_RequestRescheduleTraining_Handler, }, { MethodName: "RejectRescheduleTraining", Handler: _BFF_RejectRescheduleTraining_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "bff/v1/bff.proto", }
BFF_ServiceDesc is the grpc.ServiceDesc for BFF service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_bff_v1_bff_proto protoreflect.FileDescriptor
Functions ¶
func RegisterBFFHTTPServer ¶
func RegisterBFFHTTPServer(s *http.Server, srv BFFHTTPServer)
func RegisterBFFServer ¶
func RegisterBFFServer(s grpc.ServiceRegistrar, srv BFFServer)
Types ¶
type BFFClient ¶
type BFFClient interface {
IsHourAvailable(ctx context.Context, in *IsHourAvailableRequest, opts ...grpc.CallOption) (*IsHourAvailableResponse, error)
ScheduleTraining(ctx context.Context, in *UpdateHourRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
GetTrainerAvailableHours(ctx context.Context, in *GetTrainerAvailableHoursRequest, opts ...grpc.CallOption) (*GetTrainerAvailableHoursRespone, error)
MakeHourAvailable(ctx context.Context, in *MakeHourAvailableRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
GetTraining(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*v1.GetTrainingResponse, error)
CreateTraining(ctx context.Context, in *v1.CreateTrainingRequest, opts ...grpc.CallOption) (*v1.CreateTrainingResponse, error)
CancelTraining(ctx context.Context, in *v1.CancelTrainingRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
RescheduleTraining(ctx context.Context, in *v1.RescheduleTrainingRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
ApproveRescheduleTraining(ctx context.Context, in *v1.ApproveRescheduleTrainingRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
RequestRescheduleTraining(ctx context.Context, in *v1.RequestRescheduleTrainingRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
RejectRescheduleTraining(ctx context.Context, in *v1.RejectRescheduleTrainingRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
BFFClient is the client API for BFF service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewBFFClient ¶
func NewBFFClient(cc grpc.ClientConnInterface) BFFClient
type BFFHTTPClient ¶
type BFFHTTPClient interface {
ApproveRescheduleTraining(ctx context.Context, req *v1.ApproveRescheduleTrainingRequest, opts ...http.CallOption) (rsp *emptypb.Empty, err error)
CancelTraining(ctx context.Context, req *v1.CancelTrainingRequest, opts ...http.CallOption) (rsp *emptypb.Empty, err error)
CreateTraining(ctx context.Context, req *v1.CreateTrainingRequest, opts ...http.CallOption) (rsp *v1.CreateTrainingResponse, err error)
GetTrainerAvailableHours(ctx context.Context, req *GetTrainerAvailableHoursRequest, opts ...http.CallOption) (rsp *GetTrainerAvailableHoursRespone, err error)
GetTraining(ctx context.Context, req *emptypb.Empty, opts ...http.CallOption) (rsp *v1.GetTrainingResponse, err error)
MakeHourAvailable(ctx context.Context, req *MakeHourAvailableRequest, opts ...http.CallOption) (rsp *emptypb.Empty, err error)
RejectRescheduleTraining(ctx context.Context, req *v1.RejectRescheduleTrainingRequest, opts ...http.CallOption) (rsp *emptypb.Empty, err error)
RequestRescheduleTraining(ctx context.Context, req *v1.RequestRescheduleTrainingRequest, opts ...http.CallOption) (rsp *emptypb.Empty, err error)
RescheduleTraining(ctx context.Context, req *v1.RescheduleTrainingRequest, opts ...http.CallOption) (rsp *emptypb.Empty, err error)
}
func NewBFFHTTPClient ¶
func NewBFFHTTPClient(client *http.Client) BFFHTTPClient
type BFFHTTPClientImpl ¶
type BFFHTTPClientImpl struct {
// contains filtered or unexported fields
}
func (*BFFHTTPClientImpl) ApproveRescheduleTraining ¶
func (c *BFFHTTPClientImpl) ApproveRescheduleTraining(ctx context.Context, in *v1.ApproveRescheduleTrainingRequest, opts ...http.CallOption) (*emptypb.Empty, error)
func (*BFFHTTPClientImpl) CancelTraining ¶
func (c *BFFHTTPClientImpl) CancelTraining(ctx context.Context, in *v1.CancelTrainingRequest, opts ...http.CallOption) (*emptypb.Empty, error)
func (*BFFHTTPClientImpl) CreateTraining ¶
func (c *BFFHTTPClientImpl) CreateTraining(ctx context.Context, in *v1.CreateTrainingRequest, opts ...http.CallOption) (*v1.CreateTrainingResponse, error)
func (*BFFHTTPClientImpl) GetTrainerAvailableHours ¶
func (c *BFFHTTPClientImpl) GetTrainerAvailableHours(ctx context.Context, in *GetTrainerAvailableHoursRequest, opts ...http.CallOption) (*GetTrainerAvailableHoursRespone, error)
func (*BFFHTTPClientImpl) GetTraining ¶
func (c *BFFHTTPClientImpl) GetTraining(ctx context.Context, in *emptypb.Empty, opts ...http.CallOption) (*v1.GetTrainingResponse, error)
func (*BFFHTTPClientImpl) MakeHourAvailable ¶
func (c *BFFHTTPClientImpl) MakeHourAvailable(ctx context.Context, in *MakeHourAvailableRequest, opts ...http.CallOption) (*emptypb.Empty, error)
func (*BFFHTTPClientImpl) MakeHourUnavailable ¶
func (c *BFFHTTPClientImpl) MakeHourUnavailable(ctx context.Context, in *MakeHourUnavailableRequest, opts ...http.CallOption) (*emptypb.Empty, error)
func (*BFFHTTPClientImpl) RejectRescheduleTraining ¶
func (c *BFFHTTPClientImpl) RejectRescheduleTraining(ctx context.Context, in *v1.RejectRescheduleTrainingRequest, opts ...http.CallOption) (*emptypb.Empty, error)
func (*BFFHTTPClientImpl) RequestRescheduleTraining ¶
func (c *BFFHTTPClientImpl) RequestRescheduleTraining(ctx context.Context, in *v1.RequestRescheduleTrainingRequest, opts ...http.CallOption) (*emptypb.Empty, error)
func (*BFFHTTPClientImpl) RescheduleTraining ¶
func (c *BFFHTTPClientImpl) RescheduleTraining(ctx context.Context, in *v1.RescheduleTrainingRequest, opts ...http.CallOption) (*emptypb.Empty, error)
type BFFHTTPServer ¶
type BFFHTTPServer interface {
ApproveRescheduleTraining(context.Context, *v1.ApproveRescheduleTrainingRequest) (*emptypb.Empty, error)
CancelTraining(context.Context, *v1.CancelTrainingRequest) (*emptypb.Empty, error)
CreateTraining(context.Context, *v1.CreateTrainingRequest) (*v1.CreateTrainingResponse, error)
GetTrainerAvailableHours(context.Context, *GetTrainerAvailableHoursRequest) (*GetTrainerAvailableHoursRespone, error)
GetTraining(context.Context, *emptypb.Empty) (*v1.GetTrainingResponse, error)
MakeHourAvailable(context.Context, *MakeHourAvailableRequest) (*emptypb.Empty, error)
RejectRescheduleTraining(context.Context, *v1.RejectRescheduleTrainingRequest) (*emptypb.Empty, error)
RequestRescheduleTraining(context.Context, *v1.RequestRescheduleTrainingRequest) (*emptypb.Empty, error)
RescheduleTraining(context.Context, *v1.RescheduleTrainingRequest) (*emptypb.Empty, error)
}
type BFFServer ¶
type BFFServer interface {
IsHourAvailable(context.Context, *IsHourAvailableRequest) (*IsHourAvailableResponse, error)
ScheduleTraining(context.Context, *UpdateHourRequest) (*emptypb.Empty, error)
GetTrainerAvailableHours(context.Context, *GetTrainerAvailableHoursRequest) (*GetTrainerAvailableHoursRespone, error)
MakeHourAvailable(context.Context, *MakeHourAvailableRequest) (*emptypb.Empty, error)
GetTraining(context.Context, *emptypb.Empty) (*v1.GetTrainingResponse, error)
CreateTraining(context.Context, *v1.CreateTrainingRequest) (*v1.CreateTrainingResponse, error)
CancelTraining(context.Context, *v1.CancelTrainingRequest) (*emptypb.Empty, error)
RescheduleTraining(context.Context, *v1.RescheduleTrainingRequest) (*emptypb.Empty, error)
ApproveRescheduleTraining(context.Context, *v1.ApproveRescheduleTrainingRequest) (*emptypb.Empty, error)
RequestRescheduleTraining(context.Context, *v1.RequestRescheduleTrainingRequest) (*emptypb.Empty, error)
RejectRescheduleTraining(context.Context, *v1.RejectRescheduleTrainingRequest) (*emptypb.Empty, error)
// contains filtered or unexported methods
}
BFFServer is the server API for BFF service. All implementations must embed UnimplementedBFFServer for forward compatibility
type GetTrainerAvailableHoursRequest ¶
type GetTrainerAvailableHoursRequest struct {
DateFrom *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=date_from,json=dateFrom,proto3" json:"date_from,omitempty"`
DateTo *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=date_to,json=dateTo,proto3" json:"date_to,omitempty"`
// contains filtered or unexported fields
}
func (*GetTrainerAvailableHoursRequest) Descriptor
deprecated
func (*GetTrainerAvailableHoursRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetTrainerAvailableHoursRequest.ProtoReflect.Descriptor instead.
func (*GetTrainerAvailableHoursRequest) GetDateFrom ¶
func (x *GetTrainerAvailableHoursRequest) GetDateFrom() *timestamppb.Timestamp
func (*GetTrainerAvailableHoursRequest) GetDateTo ¶
func (x *GetTrainerAvailableHoursRequest) GetDateTo() *timestamppb.Timestamp
func (*GetTrainerAvailableHoursRequest) ProtoMessage ¶
func (*GetTrainerAvailableHoursRequest) ProtoMessage()
func (*GetTrainerAvailableHoursRequest) ProtoReflect ¶
func (x *GetTrainerAvailableHoursRequest) ProtoReflect() protoreflect.Message
func (*GetTrainerAvailableHoursRequest) Reset ¶
func (x *GetTrainerAvailableHoursRequest) Reset()
func (*GetTrainerAvailableHoursRequest) String ¶
func (x *GetTrainerAvailableHoursRequest) String() string
type GetTrainerAvailableHoursRespone ¶
type GetTrainerAvailableHoursRespone struct {
Dates []*GetTrainerAvailableHoursRespone_Date `protobuf:"bytes,1,rep,name=dates,proto3" json:"dates,omitempty"`
// contains filtered or unexported fields
}
func (*GetTrainerAvailableHoursRespone) Descriptor
deprecated
func (*GetTrainerAvailableHoursRespone) Descriptor() ([]byte, []int)
Deprecated: Use GetTrainerAvailableHoursRespone.ProtoReflect.Descriptor instead.
func (*GetTrainerAvailableHoursRespone) GetDates ¶
func (x *GetTrainerAvailableHoursRespone) GetDates() []*GetTrainerAvailableHoursRespone_Date
func (*GetTrainerAvailableHoursRespone) ProtoMessage ¶
func (*GetTrainerAvailableHoursRespone) ProtoMessage()
func (*GetTrainerAvailableHoursRespone) ProtoReflect ¶
func (x *GetTrainerAvailableHoursRespone) ProtoReflect() protoreflect.Message
func (*GetTrainerAvailableHoursRespone) Reset ¶
func (x *GetTrainerAvailableHoursRespone) Reset()
func (*GetTrainerAvailableHoursRespone) String ¶
func (x *GetTrainerAvailableHoursRespone) String() string
type GetTrainerAvailableHoursRespone_Date ¶
type GetTrainerAvailableHoursRespone_Date struct {
Date *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=date,proto3" json:"date,omitempty"`
HasFreeHours bool `protobuf:"varint,2,opt,name=Has_free_hours,json=HasFreeHours,proto3" json:"Has_free_hours,omitempty"`
Hours []*GetTrainerAvailableHoursRespone_Hour `protobuf:"bytes,3,rep,name=hours,proto3" json:"hours,omitempty"`
// contains filtered or unexported fields
}
func (*GetTrainerAvailableHoursRespone_Date) Descriptor
deprecated
func (*GetTrainerAvailableHoursRespone_Date) Descriptor() ([]byte, []int)
Deprecated: Use GetTrainerAvailableHoursRespone_Date.ProtoReflect.Descriptor instead.
func (*GetTrainerAvailableHoursRespone_Date) GetDate ¶
func (x *GetTrainerAvailableHoursRespone_Date) GetDate() *timestamppb.Timestamp
func (*GetTrainerAvailableHoursRespone_Date) GetHasFreeHours ¶
func (x *GetTrainerAvailableHoursRespone_Date) GetHasFreeHours() bool
func (*GetTrainerAvailableHoursRespone_Date) GetHours ¶
func (x *GetTrainerAvailableHoursRespone_Date) GetHours() []*GetTrainerAvailableHoursRespone_Hour
func (*GetTrainerAvailableHoursRespone_Date) ProtoMessage ¶
func (*GetTrainerAvailableHoursRespone_Date) ProtoMessage()
func (*GetTrainerAvailableHoursRespone_Date) ProtoReflect ¶
func (x *GetTrainerAvailableHoursRespone_Date) ProtoReflect() protoreflect.Message
func (*GetTrainerAvailableHoursRespone_Date) Reset ¶
func (x *GetTrainerAvailableHoursRespone_Date) Reset()
func (*GetTrainerAvailableHoursRespone_Date) String ¶
func (x *GetTrainerAvailableHoursRespone_Date) String() string
type GetTrainerAvailableHoursRespone_Hour ¶
type GetTrainerAvailableHoursRespone_Hour struct {
Available bool `protobuf:"varint,1,opt,name=available,proto3" json:"available,omitempty"`
HasTrainingScheduled bool `protobuf:"varint,2,opt,name=has_training_scheduled,json=hasTrainingScheduled,proto3" json:"has_training_scheduled,omitempty"`
Hour *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=hour,proto3" json:"hour,omitempty"`
// contains filtered or unexported fields
}
func (*GetTrainerAvailableHoursRespone_Hour) Descriptor
deprecated
func (*GetTrainerAvailableHoursRespone_Hour) Descriptor() ([]byte, []int)
Deprecated: Use GetTrainerAvailableHoursRespone_Hour.ProtoReflect.Descriptor instead.
func (*GetTrainerAvailableHoursRespone_Hour) GetAvailable ¶
func (x *GetTrainerAvailableHoursRespone_Hour) GetAvailable() bool
func (*GetTrainerAvailableHoursRespone_Hour) GetHasTrainingScheduled ¶
func (x *GetTrainerAvailableHoursRespone_Hour) GetHasTrainingScheduled() bool
func (*GetTrainerAvailableHoursRespone_Hour) GetHour ¶
func (x *GetTrainerAvailableHoursRespone_Hour) GetHour() *timestamppb.Timestamp
func (*GetTrainerAvailableHoursRespone_Hour) ProtoMessage ¶
func (*GetTrainerAvailableHoursRespone_Hour) ProtoMessage()
func (*GetTrainerAvailableHoursRespone_Hour) ProtoReflect ¶
func (x *GetTrainerAvailableHoursRespone_Hour) ProtoReflect() protoreflect.Message
func (*GetTrainerAvailableHoursRespone_Hour) Reset ¶
func (x *GetTrainerAvailableHoursRespone_Hour) Reset()
func (*GetTrainerAvailableHoursRespone_Hour) String ¶
func (x *GetTrainerAvailableHoursRespone_Hour) String() string
type IsHourAvailableRequest ¶
type IsHourAvailableRequest struct {
Time *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=time,proto3" json:"time,omitempty"`
// contains filtered or unexported fields
}
func (*IsHourAvailableRequest) Descriptor
deprecated
func (*IsHourAvailableRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsHourAvailableRequest.ProtoReflect.Descriptor instead.
func (*IsHourAvailableRequest) GetTime ¶
func (x *IsHourAvailableRequest) GetTime() *timestamppb.Timestamp
func (*IsHourAvailableRequest) ProtoMessage ¶
func (*IsHourAvailableRequest) ProtoMessage()
func (*IsHourAvailableRequest) ProtoReflect ¶
func (x *IsHourAvailableRequest) ProtoReflect() protoreflect.Message
func (*IsHourAvailableRequest) Reset ¶
func (x *IsHourAvailableRequest) Reset()
func (*IsHourAvailableRequest) String ¶
func (x *IsHourAvailableRequest) String() string
type IsHourAvailableResponse ¶
type IsHourAvailableResponse struct {
IsAvailable bool `protobuf:"varint,1,opt,name=is_available,json=isAvailable,proto3" json:"is_available,omitempty"`
// contains filtered or unexported fields
}
func (*IsHourAvailableResponse) Descriptor
deprecated
func (*IsHourAvailableResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsHourAvailableResponse.ProtoReflect.Descriptor instead.
func (*IsHourAvailableResponse) GetIsAvailable ¶
func (x *IsHourAvailableResponse) GetIsAvailable() bool
func (*IsHourAvailableResponse) ProtoMessage ¶
func (*IsHourAvailableResponse) ProtoMessage()
func (*IsHourAvailableResponse) ProtoReflect ¶
func (x *IsHourAvailableResponse) ProtoReflect() protoreflect.Message
func (*IsHourAvailableResponse) Reset ¶
func (x *IsHourAvailableResponse) Reset()
func (*IsHourAvailableResponse) String ¶
func (x *IsHourAvailableResponse) String() string
type MakeHourAvailableRequest ¶
type MakeHourAvailableRequest struct {
Time []*timestamppb.Timestamp `protobuf:"bytes,1,rep,name=time,proto3" json:"time,omitempty"`
// contains filtered or unexported fields
}
func (*MakeHourAvailableRequest) Descriptor
deprecated
func (*MakeHourAvailableRequest) Descriptor() ([]byte, []int)
Deprecated: Use MakeHourAvailableRequest.ProtoReflect.Descriptor instead.
func (*MakeHourAvailableRequest) GetTime ¶
func (x *MakeHourAvailableRequest) GetTime() []*timestamppb.Timestamp
func (*MakeHourAvailableRequest) ProtoMessage ¶
func (*MakeHourAvailableRequest) ProtoMessage()
func (*MakeHourAvailableRequest) ProtoReflect ¶
func (x *MakeHourAvailableRequest) ProtoReflect() protoreflect.Message
func (*MakeHourAvailableRequest) Reset ¶
func (x *MakeHourAvailableRequest) Reset()
func (*MakeHourAvailableRequest) String ¶
func (x *MakeHourAvailableRequest) String() string
type MakeHourUnavailableRequest ¶
type MakeHourUnavailableRequest struct {
// contains filtered or unexported fields
}
func (*MakeHourUnavailableRequest) Descriptor
deprecated
func (*MakeHourUnavailableRequest) Descriptor() ([]byte, []int)
Deprecated: Use MakeHourUnavailableRequest.ProtoReflect.Descriptor instead.
func (*MakeHourUnavailableRequest) GetTime ¶
func (x *MakeHourUnavailableRequest) GetTime() []*timestamppb.Timestamp
func (*MakeHourUnavailableRequest) ProtoMessage ¶
func (*MakeHourUnavailableRequest) ProtoMessage()
func (*MakeHourUnavailableRequest) ProtoReflect ¶
func (x *MakeHourUnavailableRequest) ProtoReflect() protoreflect.Message
func (*MakeHourUnavailableRequest) Reset ¶
func (x *MakeHourUnavailableRequest) Reset()
func (*MakeHourUnavailableRequest) String ¶
func (x *MakeHourUnavailableRequest) String() string
type UnimplementedBFFServer ¶
type UnimplementedBFFServer struct {
}
UnimplementedBFFServer must be embedded to have forward compatible implementations.
func (UnimplementedBFFServer) ApproveRescheduleTraining ¶
func (UnimplementedBFFServer) ApproveRescheduleTraining(context.Context, *v1.ApproveRescheduleTrainingRequest) (*emptypb.Empty, error)
func (UnimplementedBFFServer) CancelTraining ¶
func (UnimplementedBFFServer) CancelTraining(context.Context, *v1.CancelTrainingRequest) (*emptypb.Empty, error)
func (UnimplementedBFFServer) CreateTraining ¶
func (UnimplementedBFFServer) CreateTraining(context.Context, *v1.CreateTrainingRequest) (*v1.CreateTrainingResponse, error)
func (UnimplementedBFFServer) GetTrainerAvailableHours ¶
func (UnimplementedBFFServer) GetTrainerAvailableHours(context.Context, *GetTrainerAvailableHoursRequest) (*GetTrainerAvailableHoursRespone, error)
func (UnimplementedBFFServer) GetTraining ¶
func (UnimplementedBFFServer) GetTraining(context.Context, *emptypb.Empty) (*v1.GetTrainingResponse, error)
func (UnimplementedBFFServer) IsHourAvailable ¶
func (UnimplementedBFFServer) IsHourAvailable(context.Context, *IsHourAvailableRequest) (*IsHourAvailableResponse, error)
func (UnimplementedBFFServer) MakeHourAvailable ¶
func (UnimplementedBFFServer) MakeHourAvailable(context.Context, *MakeHourAvailableRequest) (*emptypb.Empty, error)
func (UnimplementedBFFServer) MakeHourUnavailable ¶
func (UnimplementedBFFServer) MakeHourUnavailable(context.Context, *MakeHourUnavailableRequest) (*emptypb.Empty, error)
func (UnimplementedBFFServer) RejectRescheduleTraining ¶
func (UnimplementedBFFServer) RejectRescheduleTraining(context.Context, *v1.RejectRescheduleTrainingRequest) (*emptypb.Empty, error)
func (UnimplementedBFFServer) RequestRescheduleTraining ¶
func (UnimplementedBFFServer) RequestRescheduleTraining(context.Context, *v1.RequestRescheduleTrainingRequest) (*emptypb.Empty, error)
func (UnimplementedBFFServer) RescheduleTraining ¶
func (UnimplementedBFFServer) RescheduleTraining(context.Context, *v1.RescheduleTrainingRequest) (*emptypb.Empty, error)
func (UnimplementedBFFServer) ScheduleTraining ¶
func (UnimplementedBFFServer) ScheduleTraining(context.Context, *UpdateHourRequest) (*emptypb.Empty, error)
type UnsafeBFFServer ¶
type UnsafeBFFServer interface {
// contains filtered or unexported methods
}
UnsafeBFFServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BFFServer will result in compilation errors.
type UpdateHourRequest ¶
type UpdateHourRequest struct {
Time *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=time,proto3" json:"time,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateHourRequest) Descriptor
deprecated
func (*UpdateHourRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateHourRequest.ProtoReflect.Descriptor instead.
func (*UpdateHourRequest) GetTime ¶
func (x *UpdateHourRequest) GetTime() *timestamppb.Timestamp
func (*UpdateHourRequest) ProtoMessage ¶
func (*UpdateHourRequest) ProtoMessage()
func (*UpdateHourRequest) ProtoReflect ¶
func (x *UpdateHourRequest) ProtoReflect() protoreflect.Message
func (*UpdateHourRequest) Reset ¶
func (x *UpdateHourRequest) Reset()
func (*UpdateHourRequest) String ¶
func (x *UpdateHourRequest) String() string