Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // if we expect that the user of the function may be interested with concrete error, // it's a good idea to provide variable with this error ErrNoUserInContext = errors.New("no user in context") )
Functions ¶
func NewGcGrpcServerToken ¶
func NewGcGrpcServerToken(grpcAddr string) credentials.PerRPCCredentials
Types ¶
Click to show internal directories.
Click to hide internal directories.